@@ -1,4 +1,4 @@
-# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of logilab-database.
@@ -48,20 +48,14 @@ db._ADAPTER_DIRECTORY.update({
 class _SqlServer2005FuncHelper(db._GenericAdvFuncHelper):
     backend_name = 'sqlserver2005'
     ilike_support = False
-    TYPE_MAPPING = {
-        'String' :   'nvarchar(max)',
-        'Int' :      'integer',
-        'Float' :    'float',
-        'Decimal' :  'decimal',
-        'Boolean' :  'bit',
-        'Date' :     'smalldatetime',
-        'Time' :     'time',
-        'Datetime' : 'datetime',
-        'Interval' : 'interval',
-        'Password' : 'varbinary(255)',
-        'Bytes' :    'varbinary(max)',
-        'SizeConstrainedString': 'nvarchar(%s)',
-        }
+    TYPE_MAPPING = db._GenericAdvFuncHelper.TYPE_MAPPING.copy()
+    TYPE_MAPPING['String'] =   'nvarchar(max)'
+    TYPE_MAPPING['Boolean'] =  'bit'
+    TYPE_MAPPING['Date'] =     'smalldatetime'
+    TYPE_MAPPING['Datetime'] = 'datetime'
+    TYPE_MAPPING['Password'] = 'varbinary(255)'
+    TYPE_MAPPING['Bytes'] =    'varbinary(max)'
+    TYPE_MAPPING['SizeConstrainedString'] = 'nvarchar(%s)'
 
     def list_tables(self, cursor):
         """return the list of tables of a database"""
@@ -311,8 +305,8 @@ AND j.column_id = k.column_id;"""
             try:
                 size = os.path.getsize(file_share_filename)
             except OSError, exc:
+                self.logger.exception('error accessing %s', file_share_filename)
                 err_count += 1
-                print exc
             if size > prev_size:
                 same_size_count = 0
                 prev_size = size
